<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Cleancrm\Advancedcrm\Http\Requests\CalendarEventPriorityRequest;
use Cleancrm\Advancedcrm\Interfaces\CalendarEventPriorityRepositoryInterface;
use Cleancrm\Advancedcrm\Models\CalendarEventPriority;

/**
 * Resource controller class for calendar_event_priority.
 */
class CalendarEventPriorityResourceController extends BaseController
{

    /**
     * Initialize calendar_event_priority resource controller.
     *
     * @param type CalendarEventPriorityRepositoryInterface $calendar_event_priority
     *
     * @return null
     */
    public function __construct(CalendarEventPriorityRepositoryInterface $calendar_event_priority)
    {
        parent::__construct();
        $this->repository = $calendar_event_priority;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Cleancrm\Advancedcrm\Repositories\Criteria\CalendarEventPriorityResourceCriteria::class);
    }

    /**
     * Display a list of calendar_event_priority.
     *
     * @return Response
     */
    public function index(CalendarEventPriorityRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Cleancrm\Advancedcrm\Repositories\Presenter\CalendarEventPriorityPresenter::class)
                ->$function();
        }

        $calendar_event_priorities = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('advancedcrm::calendar_event_priority.names'))
            ->view('advancedcrm::calendar_event_priority.index', true)
            ->data(compact('calendar_event_priorities', 'view'))
            ->output();
    }

    /**
     * Display calendar_event_priority.
     *
     * @param Request $request
     * @param Model   $calendar_event_priority
     *
     * @return Response
     */
    public function show(CalendarEventPriorityRequest $request, CalendarEventPriority $calendar_event_priority)
    {

        if ($calendar_event_priority->exists) {
            $view = 'advancedcrm::calendar_event_priority.show';
        } else {
            $view = 'advancedcrm::calendar_event_priority.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('advancedcrm::calendar_event_priority.name'))
            ->data(compact('calendar_event_priority'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new calendar_event_priority.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CalendarEventPriorityRequest $request)
    {

        $calendar_event_priority = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('advancedcrm::calendar_event_priority.name')) 
            ->view('advancedcrm::calendar_event_priority.create', true) 
            ->data(compact('calendar_event_priority'))
            ->output();
    }

    /**
     * Create new calendar_event_priority.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CalendarEventPriorityRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $calendar_event_priority                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('advancedcrm::calendar_event_priority.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('advancedcrm/calendar_event_priority/' . $calendar_event_priority->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/advancedcrm/calendar_event_priority'))
                ->redirect();
        }

    }

    /**
     * Show calendar_event_priority for editing.
     *
     * @param Request $request
     * @param Model   $calendar_event_priority
     *
     * @return Response
     */
    public function edit(CalendarEventPriorityRequest $request, CalendarEventPriority $calendar_event_priority)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('advancedcrm::calendar_event_priority.name'))
            ->view('advancedcrm::calendar_event_priority.edit', true)
            ->data(compact('calendar_event_priority'))
            ->output();
    }

    /**
     * Update the calendar_event_priority.
     *
     * @param Request $request
     * @param Model   $calendar_event_priority
     *
     * @return Response
     */
    public function update(CalendarEventPriorityRequest $request, CalendarEventPriority $calendar_event_priority)
    {
        try {
            $attributes = $request->all();

            $calendar_event_priority->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('advancedcrm::calendar_event_priority.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('advancedcrm/calendar_event_priority/' . $calendar_event_priority->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advancedcrm/calendar_event_priority/' . $calendar_event_priority->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the calendar_event_priority.
     *
     * @param Model   $calendar_event_priority
     *
     * @return Response
     */
    public function destroy(CalendarEventPriorityRequest $request, CalendarEventPriority $calendar_event_priority)
    {
        try {

            $calendar_event_priority->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('advancedcrm::calendar_event_priority.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('advancedcrm/calendar_event_priority/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advancedcrm/calendar_event_priority/' . $calendar_event_priority->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple calendar_event_priority.
     *
     * @param Model   $calendar_event_priority
     *
     * @return Response
     */
    public function delete(CalendarEventPriorityRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('advancedcrm::calendar_event_priority.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('advancedcrm/calendar_event_priority'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/advancedcrm/calendar_event_priority'))
                ->redirect();
        }

    }

    /**
     * Restore deleted calendar_event_priorities.
     *
     * @param Model   $calendar_event_priority
     *
     * @return Response
     */
    public function restore(CalendarEventPriorityRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('advancedcrm::calendar_event_priority.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/advancedcrm/calendar_event_priority'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/advancedcrm/calendar_event_priority/'))
                ->redirect();
        }

    }

}
