<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Cleancrm\Advancedcrm\Http\Requests\CalendarEventStatusRequest;
use Cleancrm\Advancedcrm\Models\CalendarEventStatus;

/**
 * Admin web controller class.
 */
class CalendarEventStatusWorkflowController extends BaseController
{

    /**
     * Workflow controller function for calendar_event_status.
     *
     * @param Model   $calendar_event_status
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CalendarEventStatusRequest $request, CalendarEventStatus $calendar_event_status, $step)
    {

        try {

            $calendar_event_status->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('advancedcrm::calendar_event_status.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/calendar_event_status/calendar_event_status/' . $calendar_event_status->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/calendar_event_status/calendar_event_status/' . $calendar_event_status->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for calendar_event_status.
     *
     * @param Model   $calendar_event_status
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(CalendarEventStatus $calendar_event_status, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $calendar_event_status->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('advancedcrm::calendar_event_status.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar_event_status.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar_event_status.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar_event_status.message', $data)->render();

        }

    }
}
