<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Cleancrm\Advancedcrm\Http\Requests\CalendarEventRequest;
use Cleancrm\Advancedcrm\Models\CalendarEvent;

/**
 * Admin web controller class.
 */
class CalendarEventWorkflowController extends BaseController
{

    /**
     * Workflow controller function for calendar_event.
     *
     * @param Model   $calendar_event
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CalendarEventRequest $request, CalendarEvent $calendar_event, $step)
    {

        try {

            $calendar_event->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('advancedcrm::calendar_event.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/calendar_event/calendar_event/' . $calendar_event->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/calendar_event/calendar_event/' . $calendar_event->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for calendar_event.
     *
     * @param Model   $calendar_event
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(CalendarEvent $calendar_event, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $calendar_event->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('advancedcrm::calendar_event.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar_event.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar_event.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar_event.message', $data)->render();

        }

    }
}
