<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Cleancrm\Advancedcrm\Http\Requests\CalendarRequest;
use Cleancrm\Advancedcrm\Models\Calendar;

/**
 * Admin web controller class.
 */
class CalendarWorkflowController extends BaseController
{

    /**
     * Workflow controller function for calendar.
     *
     * @param Model   $calendar
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CalendarRequest $request, Calendar $calendar, $step)
    {

        try {

            $calendar->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('advancedcrm::calendar.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/calendar/calendar/' . $calendar->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/calendar/calendar/' . $calendar->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for calendar.
     *
     * @param Model   $calendar
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Calendar $calendar, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $calendar->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('advancedcrm::calendar.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.calendar.message', $data)->render();

        }

    }
}
