<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Cleancrm\Advancedcrm\Interfaces\CustomerRepositoryInterface;

class CustomerPublicController extends BaseController
{
    // use CustomerWorkflow;

    /**
     * Constructor.
     *
     * @param type \Cleancrm\Customer\Interfaces\CustomerRepositoryInterface $customer
     *
     * @return type
     */
    public function __construct(CustomerRepositoryInterface $customer)
    {
        $this->repository = $customer;
        parent::__construct();
    }

    /**
     * Show customer's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $customers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$advancedcrm::customer.names'))
            ->view('advancedcrm::customer.index')
            ->data(compact('customers'))
            ->output();
    }


    /**
     * Show customer.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $customer = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$customer->name . trans('advancedcrm::customer.name'))
            ->view('advancedcrm::customer.show')
            ->data(compact('customer'))
            ->output();
    }

}
