<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Cleancrm\Advancedcrm\Http\Requests\LeadSourceRequest;
use Cleancrm\Advancedcrm\Models\LeadSource;

/**
 * Admin web controller class.
 */
class LeadSourceWorkflowController extends BaseController
{

    /**
     * Workflow controller function for lead_source.
     *
     * @param Model   $lead_source
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(LeadSourceRequest $request, LeadSource $lead_source, $step)
    {

        try {

            $lead_source->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('advancedcrm::lead_source.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/lead_source/lead_source/' . $lead_source->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/lead_source/lead_source/' . $lead_source->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for lead_source.
     *
     * @param Model   $lead_source
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(LeadSource $lead_source, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $lead_source->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('advancedcrm::lead_source.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.lead_source.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.lead_source.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.lead_source.message', $data)->render();

        }

    }
}
