<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Cleancrm\Advancedcrm\Http\Requests\OpportunityRequest;
use Cleancrm\Advancedcrm\Models\Opportunity;

/**
 * Admin web controller class.
 */
class OpportunityWorkflowController extends BaseController
{

    /**
     * Workflow controller function for opportunity.
     *
     * @param Model   $opportunity
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(OpportunityRequest $request, Opportunity $opportunity, $step)
    {

        try {

            $opportunity->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('advancedcrm::opportunity.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/opportunity/opportunity/' . $opportunity->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/opportunity/opportunity/' . $opportunity->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for opportunity.
     *
     * @param Model   $opportunity
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Opportunity $opportunity, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $opportunity->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('advancedcrm::opportunity.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.opportunity.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.opportunity.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.opportunity.message', $data)->render();

        }

    }
}
