<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Cleancrm\Advancedcrm\Http\Requests\RelationAddressRequest;
use Cleancrm\Advancedcrm\Interfaces\RelationAddressRepositoryInterface;
use Cleancrm\Advancedcrm\Models\RelationAddress;

/**
 * Resource controller class for relation_address.
 */
class RelationAddressResourceController extends BaseController
{

    /**
     * Initialize relation_address resource controller.
     *
     * @param type RelationAddressRepositoryInterface $relation_address
     *
     * @return null
     */
    public function __construct(RelationAddressRepositoryInterface $relation_address)
    {
        parent::__construct();
        $this->repository = $relation_address;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Cleancrm\Advancedcrm\Repositories\Criteria\RelationAddressResourceCriteria::class);
    }

    /**
     * Display a list of relation_address.
     *
     * @return Response
     */
    public function index(RelationAddressRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Cleancrm\Advancedcrm\Repositories\Presenter\RelationAddressPresenter::class)
                ->$function();
        }

        $relation_addresses = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('advancedcrm::relation_address.names'))
            ->view('advancedcrm::relation_address.index', true)
            ->data(compact('relation_addresses', 'view'))
            ->output();
    }

    /**
     * Display relation_address.
     *
     * @param Request $request
     * @param Model   $relation_address
     *
     * @return Response
     */
    public function show(RelationAddressRequest $request, RelationAddress $relation_address)
    {

        if ($relation_address->exists) {
            $view = 'advancedcrm::relation_address.show';
        } else {
            $view = 'advancedcrm::relation_address.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('advancedcrm::relation_address.name'))
            ->data(compact('relation_address'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new relation_address.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(RelationAddressRequest $request)
    {

        $relation_address = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('advancedcrm::relation_address.name')) 
            ->view('advancedcrm::relation_address.create', true) 
            ->data(compact('relation_address'))
            ->output();
    }

    /**
     * Create new relation_address.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RelationAddressRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $relation_address                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('advancedcrm::relation_address.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('advancedcrm/relation_address/' . $relation_address->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/advancedcrm/relation_address'))
                ->redirect();
        }

    }

    /**
     * Show relation_address for editing.
     *
     * @param Request $request
     * @param Model   $relation_address
     *
     * @return Response
     */
    public function edit(RelationAddressRequest $request, RelationAddress $relation_address)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('advancedcrm::relation_address.name'))
            ->view('advancedcrm::relation_address.edit', true)
            ->data(compact('relation_address'))
            ->output();
    }

    /**
     * Update the relation_address.
     *
     * @param Request $request
     * @param Model   $relation_address
     *
     * @return Response
     */
    public function update(RelationAddressRequest $request, RelationAddress $relation_address)
    {
        try {
            $attributes = $request->all();

            $relation_address->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('advancedcrm::relation_address.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('advancedcrm/relation_address/' . $relation_address->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advancedcrm/relation_address/' . $relation_address->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the relation_address.
     *
     * @param Model   $relation_address
     *
     * @return Response
     */
    public function destroy(RelationAddressRequest $request, RelationAddress $relation_address)
    {
        try {

            $relation_address->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('advancedcrm::relation_address.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('advancedcrm/relation_address/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advancedcrm/relation_address/' . $relation_address->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple relation_address.
     *
     * @param Model   $relation_address
     *
     * @return Response
     */
    public function delete(RelationAddressRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('advancedcrm::relation_address.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('advancedcrm/relation_address'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/advancedcrm/relation_address'))
                ->redirect();
        }

    }

    /**
     * Restore deleted relation_addresses.
     *
     * @param Model   $relation_address
     *
     * @return Response
     */
    public function restore(RelationAddressRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('advancedcrm::relation_address.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/advancedcrm/relation_address'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/advancedcrm/relation_address/'))
                ->redirect();
        }

    }

}
