<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Cleancrm\Advancedcrm\Http\Requests\RelationStatusRequest;
use Cleancrm\Advancedcrm\Interfaces\RelationStatusRepositoryInterface;
use Cleancrm\Advancedcrm\Models\RelationStatus;

/**
 * Resource controller class for relation_status.
 */
class RelationStatusResourceController extends BaseController
{

    /**
     * Initialize relation_status resource controller.
     *
     * @param type RelationStatusRepositoryInterface $relation_status
     *
     * @return null
     */
    public function __construct(RelationStatusRepositoryInterface $relation_status)
    {
        parent::__construct();
        $this->repository = $relation_status;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Cleancrm\Advancedcrm\Repositories\Criteria\RelationStatusResourceCriteria::class);
    }

    /**
     * Display a list of relation_status.
     *
     * @return Response
     */
    public function index(RelationStatusRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Cleancrm\Advancedcrm\Repositories\Presenter\RelationStatusPresenter::class)
                ->$function();
        }

        $relation_statuses = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('advancedcrm::relation_status.names'))
            ->view('advancedcrm::relation_status.index', true)
            ->data(compact('relation_statuses', 'view'))
            ->output();
    }

    /**
     * Display relation_status.
     *
     * @param Request $request
     * @param Model   $relation_status
     *
     * @return Response
     */
    public function show(RelationStatusRequest $request, RelationStatus $relation_status)
    {

        if ($relation_status->exists) {
            $view = 'advancedcrm::relation_status.show';
        } else {
            $view = 'advancedcrm::relation_status.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('advancedcrm::relation_status.name'))
            ->data(compact('relation_status'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new relation_status.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(RelationStatusRequest $request)
    {

        $relation_status = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('advancedcrm::relation_status.name')) 
            ->view('advancedcrm::relation_status.create', true) 
            ->data(compact('relation_status'))
            ->output();
    }

    /**
     * Create new relation_status.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RelationStatusRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $relation_status                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('advancedcrm::relation_status.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('advancedcrm/relation_status/' . $relation_status->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/advancedcrm/relation_status'))
                ->redirect();
        }

    }

    /**
     * Show relation_status for editing.
     *
     * @param Request $request
     * @param Model   $relation_status
     *
     * @return Response
     */
    public function edit(RelationStatusRequest $request, RelationStatus $relation_status)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('advancedcrm::relation_status.name'))
            ->view('advancedcrm::relation_status.edit', true)
            ->data(compact('relation_status'))
            ->output();
    }

    /**
     * Update the relation_status.
     *
     * @param Request $request
     * @param Model   $relation_status
     *
     * @return Response
     */
    public function update(RelationStatusRequest $request, RelationStatus $relation_status)
    {
        try {
            $attributes = $request->all();

            $relation_status->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('advancedcrm::relation_status.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('advancedcrm/relation_status/' . $relation_status->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advancedcrm/relation_status/' . $relation_status->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the relation_status.
     *
     * @param Model   $relation_status
     *
     * @return Response
     */
    public function destroy(RelationStatusRequest $request, RelationStatus $relation_status)
    {
        try {

            $relation_status->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('advancedcrm::relation_status.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('advancedcrm/relation_status/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advancedcrm/relation_status/' . $relation_status->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple relation_status.
     *
     * @param Model   $relation_status
     *
     * @return Response
     */
    public function delete(RelationStatusRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('advancedcrm::relation_status.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('advancedcrm/relation_status'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/advancedcrm/relation_status'))
                ->redirect();
        }

    }

    /**
     * Restore deleted relation_statuses.
     *
     * @param Model   $relation_status
     *
     * @return Response
     */
    public function restore(RelationStatusRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('advancedcrm::relation_status.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/advancedcrm/relation_status'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/advancedcrm/relation_status/'))
                ->redirect();
        }

    }

}
