<?php

namespace Cleancrm\Advancedcrm\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Cleancrm\Advancedcrm\Http\Requests\VendorRequest;
use Cleancrm\Advancedcrm\Models\Vendor;

/**
 * Admin web controller class.
 */
class VendorWorkflowController extends BaseController
{

    /**
     * Workflow controller function for vendor.
     *
     * @param Model   $vendor
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(VendorRequest $request, Vendor $vendor, $step)
    {

        try {

            $vendor->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('advancedcrm::vendor.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/vendor/vendor/' . $vendor->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/vendor/vendor/' . $vendor->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for vendor.
     *
     * @param Model   $vendor
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Vendor $vendor, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $vendor->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('advancedcrm::vendor.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.vendor.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.vendor.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('advancedcrm::admin.vendor.message', $data)->render();

        }

    }
}
