<?php

namespace Cleancrm\Advancedcrm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cleancrm\Advancedcrm\Models\CalendarEventStatus;

class CalendarEventStatusPolicy
{

    /**
     * Determine if the given user can view the calendar_event_status.
     *
     * @param UserPolicy $user
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool
     */
    public function view(UserPolicy $user, CalendarEventStatus $calendar_event_status)
    {
        if ($user->canDo('advancedcrm.calendar_event_status.view') && $user->isAdmin()) {
            return true;
        }

        return $calendar_event_status->user_id == user_id() && $calendar_event_status->user_type == user_type();
    }

    /**
     * Determine if the given user can create a calendar_event_status.
     *
     * @param UserPolicy $user
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advancedcrm.calendar_event_status.create');
    }

    /**
     * Determine if the given user can update the given calendar_event_status.
     *
     * @param UserPolicy $user
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool
     */
    public function update(UserPolicy $user, CalendarEventStatus $calendar_event_status)
    {
        if ($user->canDo('advancedcrm.calendar_event_status.edit') && $user->isAdmin()) {
            return true;
        }

        return $calendar_event_status->user_id == user_id() && $calendar_event_status->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given calendar_event_status.
     *
     * @param UserPolicy $user
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CalendarEventStatus $calendar_event_status)
    {
        return $calendar_event_status->user_id == user_id() && $calendar_event_status->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given calendar_event_status.
     *
     * @param UserPolicy $user
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CalendarEventStatus $calendar_event_status)
    {
        if ($user->canDo('advancedcrm.calendar_event_status.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given calendar_event_status.
     *
     * @param UserPolicy $user
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CalendarEventStatus $calendar_event_status)
    {
        if ($user->canDo('advancedcrm.calendar_event_status.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
