<?php

namespace Cleancrm\Advancedcrm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cleancrm\Advancedcrm\Models\CrmLeadstatus;

class CrmLeadstatusPolicy
{

    /**
     * Determine if the given user can view the crm__leadstatus.
     *
     * @param UserPolicy $user
     * @param CrmLeadstatus $crm__leadstatus
     *
     * @return bool
     */
    public function view(UserPolicy $user, CrmLeadstatus $crm__leadstatus)
    {
        if ($user->canDo('advancedcrm.crm__leadstatus.view') && $user->isAdmin()) {
            return true;
        }

        return $crm__leadstatus->user_id == user_id() && $crm__leadstatus->user_type == user_type();
    }

    /**
     * Determine if the given user can create a crm__leadstatus.
     *
     * @param UserPolicy $user
     * @param CrmLeadstatus $crm__leadstatus
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advancedcrm.crm__leadstatus.create');
    }

    /**
     * Determine if the given user can update the given crm__leadstatus.
     *
     * @param UserPolicy $user
     * @param CrmLeadstatus $crm__leadstatus
     *
     * @return bool
     */
    public function update(UserPolicy $user, CrmLeadstatus $crm__leadstatus)
    {
        if ($user->canDo('advancedcrm.crm__leadstatus.edit') && $user->isAdmin()) {
            return true;
        }

        return $crm__leadstatus->user_id == user_id() && $crm__leadstatus->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given crm__leadstatus.
     *
     * @param UserPolicy $user
     * @param CrmLeadstatus $crm__leadstatus
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CrmLeadstatus $crm__leadstatus)
    {
        return $crm__leadstatus->user_id == user_id() && $crm__leadstatus->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given crm__leadstatus.
     *
     * @param UserPolicy $user
     * @param CrmLeadstatus $crm__leadstatus
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CrmLeadstatus $crm__leadstatus)
    {
        if ($user->canDo('advancedcrm.crm__leadstatus.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given crm__leadstatus.
     *
     * @param UserPolicy $user
     * @param CrmLeadstatus $crm__leadstatus
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CrmLeadstatus $crm__leadstatus)
    {
        if ($user->canDo('advancedcrm.crm__leadstatus.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
