<?php

namespace Cleancrm\Advancedcrm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cleancrm\Advancedcrm\Models\Lead;

class LeadPolicy
{

    /**
     * Determine if the given user can view the lead.
     *
     * @param UserPolicy $user
     * @param Lead $lead
     *
     * @return bool
     */
    public function view(UserPolicy $user, Lead $lead)
    {
        if ($user->canDo('advancedcrm.lead.view') && $user->isAdmin()) {
            return true;
        }

        return $lead->user_id == user_id() && $lead->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lead.
     *
     * @param UserPolicy $user
     * @param Lead $lead
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advancedcrm.lead.create');
    }

    /**
     * Determine if the given user can update the given lead.
     *
     * @param UserPolicy $user
     * @param Lead $lead
     *
     * @return bool
     */
    public function update(UserPolicy $user, Lead $lead)
    {
        if ($user->canDo('advancedcrm.lead.edit') && $user->isAdmin()) {
            return true;
        }

        return $lead->user_id == user_id() && $lead->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lead.
     *
     * @param UserPolicy $user
     * @param Lead $lead
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Lead $lead)
    {
        return $lead->user_id == user_id() && $lead->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lead.
     *
     * @param UserPolicy $user
     * @param Lead $lead
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Lead $lead)
    {
        if ($user->canDo('advancedcrm.lead.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lead.
     *
     * @param UserPolicy $user
     * @param Lead $lead
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Lead $lead)
    {
        if ($user->canDo('advancedcrm.lead.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
