<?php

namespace Cleancrm\Advancedcrm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cleancrm\Advancedcrm\Models\LeadSource;

class LeadSourcePolicy
{

    /**
     * Determine if the given user can view the lead_source.
     *
     * @param UserPolicy $user
     * @param LeadSource $lead_source
     *
     * @return bool
     */
    public function view(UserPolicy $user, LeadSource $lead_source)
    {
        if ($user->canDo('advancedcrm.lead_source.view') && $user->isAdmin()) {
            return true;
        }

        return $lead_source->user_id == user_id() && $lead_source->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lead_source.
     *
     * @param UserPolicy $user
     * @param LeadSource $lead_source
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advancedcrm.lead_source.create');
    }

    /**
     * Determine if the given user can update the given lead_source.
     *
     * @param UserPolicy $user
     * @param LeadSource $lead_source
     *
     * @return bool
     */
    public function update(UserPolicy $user, LeadSource $lead_source)
    {
        if ($user->canDo('advancedcrm.lead_source.edit') && $user->isAdmin()) {
            return true;
        }

        return $lead_source->user_id == user_id() && $lead_source->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lead_source.
     *
     * @param UserPolicy $user
     * @param LeadSource $lead_source
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LeadSource $lead_source)
    {
        return $lead_source->user_id == user_id() && $lead_source->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lead_source.
     *
     * @param UserPolicy $user
     * @param LeadSource $lead_source
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LeadSource $lead_source)
    {
        if ($user->canDo('advancedcrm.lead_source.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lead_source.
     *
     * @param UserPolicy $user
     * @param LeadSource $lead_source
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LeadSource $lead_source)
    {
        if ($user->canDo('advancedcrm.lead_source.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
