<?php

namespace Cleancrm\Advancedcrm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cleancrm\Advancedcrm\Models\OpportunityStatus;

class OpportunityStatusPolicy
{

    /**
     * Determine if the given user can view the opportunity_status.
     *
     * @param UserPolicy $user
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool
     */
    public function view(UserPolicy $user, OpportunityStatus $opportunity_status)
    {
        if ($user->canDo('advancedcrm.opportunity_status.view') && $user->isAdmin()) {
            return true;
        }

        return $opportunity_status->user_id == user_id() && $opportunity_status->user_type == user_type();
    }

    /**
     * Determine if the given user can create a opportunity_status.
     *
     * @param UserPolicy $user
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advancedcrm.opportunity_status.create');
    }

    /**
     * Determine if the given user can update the given opportunity_status.
     *
     * @param UserPolicy $user
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool
     */
    public function update(UserPolicy $user, OpportunityStatus $opportunity_status)
    {
        if ($user->canDo('advancedcrm.opportunity_status.edit') && $user->isAdmin()) {
            return true;
        }

        return $opportunity_status->user_id == user_id() && $opportunity_status->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given opportunity_status.
     *
     * @param UserPolicy $user
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, OpportunityStatus $opportunity_status)
    {
        return $opportunity_status->user_id == user_id() && $opportunity_status->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given opportunity_status.
     *
     * @param UserPolicy $user
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool
     */
    public function verify(UserPolicy $user, OpportunityStatus $opportunity_status)
    {
        if ($user->canDo('advancedcrm.opportunity_status.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given opportunity_status.
     *
     * @param UserPolicy $user
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool
     */
    public function approve(UserPolicy $user, OpportunityStatus $opportunity_status)
    {
        if ($user->canDo('advancedcrm.opportunity_status.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
