<?php

namespace Cleancrm\Advancedcrm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cleancrm\Advancedcrm\Models\RelationAddress;

class RelationAddressPolicy
{

    /**
     * Determine if the given user can view the relation_address.
     *
     * @param UserPolicy $user
     * @param RelationAddress $relation_address
     *
     * @return bool
     */
    public function view(UserPolicy $user, RelationAddress $relation_address)
    {
        if ($user->canDo('advancedcrm.relation_address.view') && $user->isAdmin()) {
            return true;
        }

        return $relation_address->user_id == user_id() && $relation_address->user_type == user_type();
    }

    /**
     * Determine if the given user can create a relation_address.
     *
     * @param UserPolicy $user
     * @param RelationAddress $relation_address
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advancedcrm.relation_address.create');
    }

    /**
     * Determine if the given user can update the given relation_address.
     *
     * @param UserPolicy $user
     * @param RelationAddress $relation_address
     *
     * @return bool
     */
    public function update(UserPolicy $user, RelationAddress $relation_address)
    {
        if ($user->canDo('advancedcrm.relation_address.edit') && $user->isAdmin()) {
            return true;
        }

        return $relation_address->user_id == user_id() && $relation_address->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given relation_address.
     *
     * @param UserPolicy $user
     * @param RelationAddress $relation_address
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RelationAddress $relation_address)
    {
        return $relation_address->user_id == user_id() && $relation_address->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given relation_address.
     *
     * @param UserPolicy $user
     * @param RelationAddress $relation_address
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RelationAddress $relation_address)
    {
        if ($user->canDo('advancedcrm.relation_address.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given relation_address.
     *
     * @param UserPolicy $user
     * @param RelationAddress $relation_address
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RelationAddress $relation_address)
    {
        if ($user->canDo('advancedcrm.relation_address.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
