<?php

namespace Cleancrm\Advancedcrm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cleancrm\Advancedcrm\Models\RelationCommunication;

class RelationCommunicationPolicy
{

    /**
     * Determine if the given user can view the relation_communication.
     *
     * @param UserPolicy $user
     * @param RelationCommunication $relation_communication
     *
     * @return bool
     */
    public function view(UserPolicy $user, RelationCommunication $relation_communication)
    {
        if ($user->canDo('advancedcrm.relation_communication.view') && $user->isAdmin()) {
            return true;
        }

        return $relation_communication->user_id == user_id() && $relation_communication->user_type == user_type();
    }

    /**
     * Determine if the given user can create a relation_communication.
     *
     * @param UserPolicy $user
     * @param RelationCommunication $relation_communication
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advancedcrm.relation_communication.create');
    }

    /**
     * Determine if the given user can update the given relation_communication.
     *
     * @param UserPolicy $user
     * @param RelationCommunication $relation_communication
     *
     * @return bool
     */
    public function update(UserPolicy $user, RelationCommunication $relation_communication)
    {
        if ($user->canDo('advancedcrm.relation_communication.edit') && $user->isAdmin()) {
            return true;
        }

        return $relation_communication->user_id == user_id() && $relation_communication->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given relation_communication.
     *
     * @param UserPolicy $user
     * @param RelationCommunication $relation_communication
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RelationCommunication $relation_communication)
    {
        return $relation_communication->user_id == user_id() && $relation_communication->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given relation_communication.
     *
     * @param UserPolicy $user
     * @param RelationCommunication $relation_communication
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RelationCommunication $relation_communication)
    {
        if ($user->canDo('advancedcrm.relation_communication.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given relation_communication.
     *
     * @param UserPolicy $user
     * @param RelationCommunication $relation_communication
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RelationCommunication $relation_communication)
    {
        if ($user->canDo('advancedcrm.relation_communication.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
