<?php

namespace Cleancrm\Advancedcrm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cleancrm\Advancedcrm\Models\Relation;

class RelationPolicy
{

    /**
     * Determine if the given user can view the relation.
     *
     * @param UserPolicy $user
     * @param Relation $relation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Relation $relation)
    {
        if ($user->canDo('advancedcrm.relation.view') && $user->isAdmin()) {
            return true;
        }

        return $relation->user_id == user_id() && $relation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a relation.
     *
     * @param UserPolicy $user
     * @param Relation $relation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advancedcrm.relation.create');
    }

    /**
     * Determine if the given user can update the given relation.
     *
     * @param UserPolicy $user
     * @param Relation $relation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Relation $relation)
    {
        if ($user->canDo('advancedcrm.relation.edit') && $user->isAdmin()) {
            return true;
        }

        return $relation->user_id == user_id() && $relation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given relation.
     *
     * @param UserPolicy $user
     * @param Relation $relation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Relation $relation)
    {
        return $relation->user_id == user_id() && $relation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given relation.
     *
     * @param UserPolicy $user
     * @param Relation $relation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Relation $relation)
    {
        if ($user->canDo('advancedcrm.relation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given relation.
     *
     * @param UserPolicy $user
     * @param Relation $relation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Relation $relation)
    {
        if ($user->canDo('advancedcrm.relation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
