<?php

namespace Cleancrm\Advancedcrm\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Cleancrm\Advancedcrm\Models\Advancedcrm;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Cleancrm\Advancedcrm\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/advancedcrm/company/*')) {
            Route::bind('company', function ($company) {
                $companyrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\CompanyRepositoryInterface');
                return $companyrepo->findorNew($company);
            });
        }

        if (Request::is('*/advancedcrm/calendar/*')) {
            Route::bind('calendar', function ($calendar) {
                $calendarrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\CalendarRepositoryInterface');
                return $calendarrepo->findorNew($calendar);
            });
        }

        if (Request::is('*/advancedcrm/calendar_event/*')) {
            Route::bind('calendar_event', function ($calendar_event) {
                $calendar_eventrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\CalendarEventRepositoryInterface');
                return $calendar_eventrepo->findorNew($calendar_event);
            });
        }

        if (Request::is('*/advancedcrm/calendar_event_status/*')) {
            Route::bind('calendar_event_status', function ($calendar_event_status) {
                $calendar_event_statusrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\CalendarEventStatusRepositoryInterface');
                return $calendar_event_statusrepo->findorNew($calendar_event_status);
            });
        }

        if (Request::is('*/advancedcrm/calendar_event_priority/*')) {
            Route::bind('calendar_event_priority', function ($calendar_event_priority) {
                $calendar_event_priorityrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\CalendarEventPriorityRepositoryInterface');
                return $calendar_event_priorityrepo->findorNew($calendar_event_priority);
            });
        }

        if (Request::is('*/advancedcrm/relation/*')) {
            Route::bind('relation', function ($relation) {
                $relationrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\RelationRepositoryInterface');
                return $relationrepo->findorNew($relation);
            });
        }

        if (Request::is('*/advancedcrm/relation_type/*')) {
            Route::bind('relation_type', function ($relation_type) {
                $relation_typerepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\RelationTypeRepositoryInterface');
                return $relation_typerepo->findorNew($relation_type);
            });
        }

        if (Request::is('*/advancedcrm/relation_status/*')) {
            Route::bind('relation_status', function ($relation_status) {
                $relation_statusrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\RelationStatusRepositoryInterface');
                return $relation_statusrepo->findorNew($relation_status);
            });
        }

        if (Request::is('*/advancedcrm/lead/*')) {
            Route::bind('lead', function ($lead) {
                $leadrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\LeadRepositoryInterface');
                return $leadrepo->findorNew($lead);
            });
        }

        if (Request::is('*/advancedcrm/crm__leadstatus/*')) {
            Route::bind('crm__leadstatus', function ($crm__leadstatus) {
                $crm__leadstatusrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\CrmLeadstatusRepositoryInterface');
                return $crm__leadstatusrepo->findorNew($crm__leadstatus);
            });
        }

        if (Request::is('*/advancedcrm/lead_source/*')) {
            Route::bind('lead_source', function ($lead_source) {
                $lead_sourcerepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\LeadSourceRepositoryInterface');
                return $lead_sourcerepo->findorNew($lead_source);
            });
        }

        if (Request::is('*/advancedcrm/opportunity/*')) {
            Route::bind('opportunity', function ($opportunity) {
                $opportunityrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\OpportunityRepositoryInterface');
                return $opportunityrepo->findorNew($opportunity);
            });
        }

        if (Request::is('*/advancedcrm/opportunity_status/*')) {
            Route::bind('opportunity_status', function ($opportunity_status) {
                $opportunity_statusrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\OpportunityStatusRepositoryInterface');
                return $opportunity_statusrepo->findorNew($opportunity_status);
            });
        }

        if (Request::is('*/advancedcrm/vendor/*')) {
            Route::bind('vendor', function ($vendor) {
                $vendorrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\VendorRepositoryInterface');
                return $vendorrepo->findorNew($vendor);
            });
        }

        if (Request::is('*/advancedcrm/customer/*')) {
            Route::bind('customer', function ($customer) {
                $customerrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\CustomerRepositoryInterface');
                return $customerrepo->findorNew($customer);
            });
        }

        if (Request::is('*/advancedcrm/relation_address/*')) {
            Route::bind('relation_address', function ($relation_address) {
                $relation_addressrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\RelationAddressRepositoryInterface');
                return $relation_addressrepo->findorNew($relation_address);
            });
        }

        if (Request::is('*/advancedcrm/relation_communication/*')) {
            Route::bind('relation_communication', function ($relation_communication) {
                $relation_communicationrepo = $this->app->make('Cleancrm\Advancedcrm\Interfaces\RelationCommunicationRepositoryInterface');
                return $relation_communicationrepo->findorNew($relation_communication);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        if(request()->segment(1) != 'api' && request()->segment(2) != 'api') {
            return;
        }

        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
