<?php

namespace Cleancrm\Advancedcrm\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Company workflow validator
        'Cleancrm\Advancedcrm\Models\Company' => \Cleancrm\Advancedcrm\Workflow\CompanyValidator::class,

        // Bind Calendar workflow validator
        'Cleancrm\Advancedcrm\Models\Calendar' => \Cleancrm\Advancedcrm\Workflow\CalendarValidator::class,

        // Bind CalendarEvent workflow validator
        'Cleancrm\Advancedcrm\Models\CalendarEvent' => \Cleancrm\Advancedcrm\Workflow\CalendarEventValidator::class,

        // Bind CalendarEventStatus workflow validator
        'Cleancrm\Advancedcrm\Models\CalendarEventStatus' => \Cleancrm\Advancedcrm\Workflow\CalendarEventStatusValidator::class,

        // Bind CalendarEventPriority workflow validator
        'Cleancrm\Advancedcrm\Models\CalendarEventPriority' => \Cleancrm\Advancedcrm\Workflow\CalendarEventPriorityValidator::class,

        // Bind Relation workflow validator
        'Cleancrm\Advancedcrm\Models\Relation' => \Cleancrm\Advancedcrm\Workflow\RelationValidator::class,

        // Bind RelationType workflow validator
        'Cleancrm\Advancedcrm\Models\RelationType' => \Cleancrm\Advancedcrm\Workflow\RelationTypeValidator::class,

        // Bind RelationStatus workflow validator
        'Cleancrm\Advancedcrm\Models\RelationStatus' => \Cleancrm\Advancedcrm\Workflow\RelationStatusValidator::class,

        // Bind Lead workflow validator
        'Cleancrm\Advancedcrm\Models\Lead' => \Cleancrm\Advancedcrm\Workflow\LeadValidator::class,

        // Bind LeadSource workflow validator
        'Cleancrm\Advancedcrm\Models\LeadSource' => \Cleancrm\Advancedcrm\Workflow\LeadSourceValidator::class,

        // Bind Opportunity workflow validator
        'Cleancrm\Advancedcrm\Models\Opportunity' => \Cleancrm\Advancedcrm\Workflow\OpportunityValidator::class,

        // Bind OpportunityStatus workflow validator
        'Cleancrm\Advancedcrm\Models\OpportunityStatus' => \Cleancrm\Advancedcrm\Workflow\OpportunityStatusValidator::class,

        // Bind Vendor workflow validator
        'Cleancrm\Advancedcrm\Models\Vendor' => \Cleancrm\Advancedcrm\Workflow\VendorValidator::class,

        // Bind Customer workflow validator
        'Cleancrm\Advancedcrm\Models\Customer' => \Cleancrm\Advancedcrm\Workflow\CustomerValidator::class,

        // Bind RelationAddress workflow validator
        'Cleancrm\Advancedcrm\Models\RelationAddress' => \Cleancrm\Advancedcrm\Workflow\RelationAddressValidator::class,

        // Bind RelationCommunication workflow validator
        'Cleancrm\Advancedcrm\Models\RelationCommunication' => \Cleancrm\Advancedcrm\Workflow\RelationCommunicationValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Company workflow actions
        'Cleancrm\Advancedcrm\Models\Company' => \Cleancrm\Advancedcrm\Workflow\CompanyAction::class,

        // Bind Calendar workflow actions
        'Cleancrm\Advancedcrm\Models\Calendar' => \Cleancrm\Advancedcrm\Workflow\CalendarAction::class,

        // Bind CalendarEvent workflow actions
        'Cleancrm\Advancedcrm\Models\CalendarEvent' => \Cleancrm\Advancedcrm\Workflow\CalendarEventAction::class,

        // Bind CalendarEventStatus workflow actions
        'Cleancrm\Advancedcrm\Models\CalendarEventStatus' => \Cleancrm\Advancedcrm\Workflow\CalendarEventStatusAction::class,

        // Bind CalendarEventPriority workflow actions
        'Cleancrm\Advancedcrm\Models\CalendarEventPriority' => \Cleancrm\Advancedcrm\Workflow\CalendarEventPriorityAction::class,

        // Bind Relation workflow actions
        'Cleancrm\Advancedcrm\Models\Relation' => \Cleancrm\Advancedcrm\Workflow\RelationAction::class,

        // Bind RelationType workflow actions
        'Cleancrm\Advancedcrm\Models\RelationType' => \Cleancrm\Advancedcrm\Workflow\RelationTypeAction::class,

        // Bind RelationStatus workflow actions
        'Cleancrm\Advancedcrm\Models\RelationStatus' => \Cleancrm\Advancedcrm\Workflow\RelationStatusAction::class,

        // Bind Lead workflow actions
        'Cleancrm\Advancedcrm\Models\Lead' => \Cleancrm\Advancedcrm\Workflow\LeadAction::class,

        // Bind LeadSource workflow actions
        'Cleancrm\Advancedcrm\Models\LeadSource' => \Cleancrm\Advancedcrm\Workflow\LeadSourceAction::class,

        // Bind Opportunity workflow actions
        'Cleancrm\Advancedcrm\Models\Opportunity' => \Cleancrm\Advancedcrm\Workflow\OpportunityAction::class,

        // Bind OpportunityStatus workflow actions
        'Cleancrm\Advancedcrm\Models\OpportunityStatus' => \Cleancrm\Advancedcrm\Workflow\OpportunityStatusAction::class,

        // Bind Vendor workflow actions
        'Cleancrm\Advancedcrm\Models\Vendor' => \Cleancrm\Advancedcrm\Workflow\VendorAction::class,

        // Bind Customer workflow actions
        'Cleancrm\Advancedcrm\Models\Customer' => \Cleancrm\Advancedcrm\Workflow\CustomerAction::class,

        // Bind RelationAddress workflow actions
        'Cleancrm\Advancedcrm\Models\RelationAddress' => \Cleancrm\Advancedcrm\Workflow\RelationAddressAction::class,

        // Bind RelationCommunication workflow actions
        'Cleancrm\Advancedcrm\Models\RelationCommunication' => \Cleancrm\Advancedcrm\Workflow\RelationCommunicationAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Company workflow notifiers
        'Cleancrm\Advancedcrm\Models\Company' => \Cleancrm\Advancedcrm\Workflow\CompanyNotifier::class,

        // Bind Calendar workflow notifiers
        'Cleancrm\Advancedcrm\Models\Calendar' => \Cleancrm\Advancedcrm\Workflow\CalendarNotifier::class,

        // Bind CalendarEvent workflow notifiers
        'Cleancrm\Advancedcrm\Models\CalendarEvent' => \Cleancrm\Advancedcrm\Workflow\CalendarEventNotifier::class,

        // Bind CalendarEventStatus workflow notifiers
        'Cleancrm\Advancedcrm\Models\CalendarEventStatus' => \Cleancrm\Advancedcrm\Workflow\CalendarEventStatusNotifier::class,

        // Bind CalendarEventPriority workflow notifiers
        'Cleancrm\Advancedcrm\Models\CalendarEventPriority' => \Cleancrm\Advancedcrm\Workflow\CalendarEventPriorityNotifier::class,

        // Bind Relation workflow notifiers
        'Cleancrm\Advancedcrm\Models\Relation' => \Cleancrm\Advancedcrm\Workflow\RelationNotifier::class,

        // Bind RelationType workflow notifiers
        'Cleancrm\Advancedcrm\Models\RelationType' => \Cleancrm\Advancedcrm\Workflow\RelationTypeNotifier::class,

        // Bind RelationStatus workflow notifiers
        'Cleancrm\Advancedcrm\Models\RelationStatus' => \Cleancrm\Advancedcrm\Workflow\RelationStatusNotifier::class,

        // Bind Lead workflow notifiers
        'Cleancrm\Advancedcrm\Models\Lead' => \Cleancrm\Advancedcrm\Workflow\LeadNotifier::class,

        // Bind LeadSource workflow notifiers
        'Cleancrm\Advancedcrm\Models\LeadSource' => \Cleancrm\Advancedcrm\Workflow\LeadSourceNotifier::class,

        // Bind Opportunity workflow notifiers
        'Cleancrm\Advancedcrm\Models\Opportunity' => \Cleancrm\Advancedcrm\Workflow\OpportunityNotifier::class,

        // Bind OpportunityStatus workflow notifiers
        'Cleancrm\Advancedcrm\Models\OpportunityStatus' => \Cleancrm\Advancedcrm\Workflow\OpportunityStatusNotifier::class,

        // Bind Vendor workflow notifiers
        'Cleancrm\Advancedcrm\Models\Vendor' => \Cleancrm\Advancedcrm\Workflow\VendorNotifier::class,

        // Bind Customer workflow notifiers
        'Cleancrm\Advancedcrm\Models\Customer' => \Cleancrm\Advancedcrm\Workflow\CustomerNotifier::class,

        // Bind RelationAddress workflow notifiers
        'Cleancrm\Advancedcrm\Models\RelationAddress' => \Cleancrm\Advancedcrm\Workflow\RelationAddressNotifier::class,

        // Bind RelationCommunication workflow notifiers
        'Cleancrm\Advancedcrm\Models\RelationCommunication' => \Cleancrm\Advancedcrm\Workflow\RelationCommunicationNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
