<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\Calendar;

class CalendarAction
{
    /**
     * Perform the complete action.
     *
     * @param Calendar $calendar
     *
     * @return Calendar
     */
    public function complete(Calendar $calendar)
    {
        try {
            $calendar->status = 'complete';
            return $calendar->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Calendar $calendar
     *
     * @return Calendar
     */public function verify(Calendar $calendar)
    {
        try {
            $calendar->status = 'verify';
            return $calendar->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Calendar $calendar
     *
     * @return Calendar
     */public function approve(Calendar $calendar)
    {
        try {
            $calendar->status = 'approve';
            return $calendar->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Calendar $calendar
     *
     * @return Calendar
     */public function publish(Calendar $calendar)
    {
        try {
            $calendar->status = 'publish';
            return $calendar->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Calendar $calendar
     *
     * @return Calendar
     */
    public function archive(Calendar $calendar)
    {
        try {
            $calendar->status = 'archive';
            return $calendar->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Calendar $calendar
     *
     * @return Calendar
     */
    public function unpublish(Calendar $calendar)
    {
        try {
            $calendar->status = 'unpublish';
            return $calendar->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
