<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\CalendarEventPriority;
use Validator;

class CalendarEventPriorityValidator
{

    /**
     * Determine if the given calendar_event_priority is valid for complete status.
     *
     * @param CalendarEventPriority $calendar_event_priority
     *
     * @return bool / Validator
     */
    public function complete(CalendarEventPriority $calendar_event_priority)
    {
        return Validator::make($calendar_event_priority->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given calendar_event_priority is valid for verify status.
     *
     * @param CalendarEventPriority $calendar_event_priority
     *
     * @return bool / Validator
     */
    public function verify(CalendarEventPriority $calendar_event_priority)
    {
        return Validator::make($calendar_event_priority->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given calendar_event_priority is valid for approve status.
     *
     * @param CalendarEventPriority $calendar_event_priority
     *
     * @return bool / Validator
     */
    public function approve(CalendarEventPriority $calendar_event_priority)
    {
        return Validator::make($calendar_event_priority->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given calendar_event_priority is valid for publish status.
     *
     * @param CalendarEventPriority $calendar_event_priority
     *
     * @return bool / Validator
     */
    public function publish(CalendarEventPriority $calendar_event_priority)
    {
        return Validator::make($calendar_event_priority->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given calendar_event_priority is valid for archive status.
     *
     * @param CalendarEventPriority $calendar_event_priority
     *
     * @return bool / Validator
     */
    public function archive(CalendarEventPriority $calendar_event_priority)
    {
        return Validator::make($calendar_event_priority->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given calendar_event_priority is valid for unpublish status.
     *
     * @param CalendarEventPriority $calendar_event_priority
     *
     * @return bool / Validator
     */
    public function unpublish(CalendarEventPriority $calendar_event_priority)
    {
        return Validator::make($calendar_event_priority->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
