<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\CalendarEventStatus;
use Validator;

class CalendarEventStatusValidator
{

    /**
     * Determine if the given calendar_event_status is valid for complete status.
     *
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool / Validator
     */
    public function complete(CalendarEventStatus $calendar_event_status)
    {
        return Validator::make($calendar_event_status->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given calendar_event_status is valid for verify status.
     *
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool / Validator
     */
    public function verify(CalendarEventStatus $calendar_event_status)
    {
        return Validator::make($calendar_event_status->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given calendar_event_status is valid for approve status.
     *
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool / Validator
     */
    public function approve(CalendarEventStatus $calendar_event_status)
    {
        return Validator::make($calendar_event_status->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given calendar_event_status is valid for publish status.
     *
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool / Validator
     */
    public function publish(CalendarEventStatus $calendar_event_status)
    {
        return Validator::make($calendar_event_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given calendar_event_status is valid for archive status.
     *
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool / Validator
     */
    public function archive(CalendarEventStatus $calendar_event_status)
    {
        return Validator::make($calendar_event_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given calendar_event_status is valid for unpublish status.
     *
     * @param CalendarEventStatus $calendar_event_status
     *
     * @return bool / Validator
     */
    public function unpublish(CalendarEventStatus $calendar_event_status)
    {
        return Validator::make($calendar_event_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
