<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\CalendarEvent;
use Validator;

class CalendarEventValidator
{

    /**
     * Determine if the given calendar_event is valid for complete status.
     *
     * @param CalendarEvent $calendar_event
     *
     * @return bool / Validator
     */
    public function complete(CalendarEvent $calendar_event)
    {
        return Validator::make($calendar_event->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given calendar_event is valid for verify status.
     *
     * @param CalendarEvent $calendar_event
     *
     * @return bool / Validator
     */
    public function verify(CalendarEvent $calendar_event)
    {
        return Validator::make($calendar_event->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given calendar_event is valid for approve status.
     *
     * @param CalendarEvent $calendar_event
     *
     * @return bool / Validator
     */
    public function approve(CalendarEvent $calendar_event)
    {
        return Validator::make($calendar_event->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given calendar_event is valid for publish status.
     *
     * @param CalendarEvent $calendar_event
     *
     * @return bool / Validator
     */
    public function publish(CalendarEvent $calendar_event)
    {
        return Validator::make($calendar_event->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given calendar_event is valid for archive status.
     *
     * @param CalendarEvent $calendar_event
     *
     * @return bool / Validator
     */
    public function archive(CalendarEvent $calendar_event)
    {
        return Validator::make($calendar_event->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given calendar_event is valid for unpublish status.
     *
     * @param CalendarEvent $calendar_event
     *
     * @return bool / Validator
     */
    public function unpublish(CalendarEvent $calendar_event)
    {
        return Validator::make($calendar_event->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
