<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\Calendar;
use Validator;

class CalendarValidator
{

    /**
     * Determine if the given calendar is valid for complete status.
     *
     * @param Calendar $calendar
     *
     * @return bool / Validator
     */
    public function complete(Calendar $calendar)
    {
        return Validator::make($calendar->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given calendar is valid for verify status.
     *
     * @param Calendar $calendar
     *
     * @return bool / Validator
     */
    public function verify(Calendar $calendar)
    {
        return Validator::make($calendar->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given calendar is valid for approve status.
     *
     * @param Calendar $calendar
     *
     * @return bool / Validator
     */
    public function approve(Calendar $calendar)
    {
        return Validator::make($calendar->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given calendar is valid for publish status.
     *
     * @param Calendar $calendar
     *
     * @return bool / Validator
     */
    public function publish(Calendar $calendar)
    {
        return Validator::make($calendar->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given calendar is valid for archive status.
     *
     * @param Calendar $calendar
     *
     * @return bool / Validator
     */
    public function archive(Calendar $calendar)
    {
        return Validator::make($calendar->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given calendar is valid for unpublish status.
     *
     * @param Calendar $calendar
     *
     * @return bool / Validator
     */
    public function unpublish(Calendar $calendar)
    {
        return Validator::make($calendar->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
