<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\Customer;

class CustomerAction
{
    /**
     * Perform the complete action.
     *
     * @param Customer $customer
     *
     * @return Customer
     */
    public function complete(Customer $customer)
    {
        try {
            $customer->status = 'complete';
            return $customer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Customer $customer
     *
     * @return Customer
     */public function verify(Customer $customer)
    {
        try {
            $customer->status = 'verify';
            return $customer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Customer $customer
     *
     * @return Customer
     */public function approve(Customer $customer)
    {
        try {
            $customer->status = 'approve';
            return $customer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Customer $customer
     *
     * @return Customer
     */public function publish(Customer $customer)
    {
        try {
            $customer->status = 'publish';
            return $customer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Customer $customer
     *
     * @return Customer
     */
    public function archive(Customer $customer)
    {
        try {
            $customer->status = 'archive';
            return $customer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Customer $customer
     *
     * @return Customer
     */
    public function unpublish(Customer $customer)
    {
        try {
            $customer->status = 'unpublish';
            return $customer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
