<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\Customer;
use Validator;

class CustomerValidator
{

    /**
     * Determine if the given customer is valid for complete status.
     *
     * @param Customer $customer
     *
     * @return bool / Validator
     */
    public function complete(Customer $customer)
    {
        return Validator::make($customer->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given customer is valid for verify status.
     *
     * @param Customer $customer
     *
     * @return bool / Validator
     */
    public function verify(Customer $customer)
    {
        return Validator::make($customer->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given customer is valid for approve status.
     *
     * @param Customer $customer
     *
     * @return bool / Validator
     */
    public function approve(Customer $customer)
    {
        return Validator::make($customer->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given customer is valid for publish status.
     *
     * @param Customer $customer
     *
     * @return bool / Validator
     */
    public function publish(Customer $customer)
    {
        return Validator::make($customer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given customer is valid for archive status.
     *
     * @param Customer $customer
     *
     * @return bool / Validator
     */
    public function archive(Customer $customer)
    {
        return Validator::make($customer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given customer is valid for unpublish status.
     *
     * @param Customer $customer
     *
     * @return bool / Validator
     */
    public function unpublish(Customer $customer)
    {
        return Validator::make($customer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
