<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\Lead;

class LeadAction
{
    /**
     * Perform the complete action.
     *
     * @param Lead $lead
     *
     * @return Lead
     */
    public function complete(Lead $lead)
    {
        try {
            $lead->status = 'complete';
            return $lead->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Lead $lead
     *
     * @return Lead
     */public function verify(Lead $lead)
    {
        try {
            $lead->status = 'verify';
            return $lead->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Lead $lead
     *
     * @return Lead
     */public function approve(Lead $lead)
    {
        try {
            $lead->status = 'approve';
            return $lead->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Lead $lead
     *
     * @return Lead
     */public function publish(Lead $lead)
    {
        try {
            $lead->status = 'publish';
            return $lead->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Lead $lead
     *
     * @return Lead
     */
    public function archive(Lead $lead)
    {
        try {
            $lead->status = 'archive';
            return $lead->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Lead $lead
     *
     * @return Lead
     */
    public function unpublish(Lead $lead)
    {
        try {
            $lead->status = 'unpublish';
            return $lead->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
