<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\LeadSource;

class LeadSourceAction
{
    /**
     * Perform the complete action.
     *
     * @param LeadSource $lead_source
     *
     * @return LeadSource
     */
    public function complete(LeadSource $lead_source)
    {
        try {
            $lead_source->status = 'complete';
            return $lead_source->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param LeadSource $lead_source
     *
     * @return LeadSource
     */public function verify(LeadSource $lead_source)
    {
        try {
            $lead_source->status = 'verify';
            return $lead_source->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param LeadSource $lead_source
     *
     * @return LeadSource
     */public function approve(LeadSource $lead_source)
    {
        try {
            $lead_source->status = 'approve';
            return $lead_source->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param LeadSource $lead_source
     *
     * @return LeadSource
     */public function publish(LeadSource $lead_source)
    {
        try {
            $lead_source->status = 'publish';
            return $lead_source->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param LeadSource $lead_source
     *
     * @return LeadSource
     */
    public function archive(LeadSource $lead_source)
    {
        try {
            $lead_source->status = 'archive';
            return $lead_source->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param LeadSource $lead_source
     *
     * @return LeadSource
     */
    public function unpublish(LeadSource $lead_source)
    {
        try {
            $lead_source->status = 'unpublish';
            return $lead_source->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
