<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\LeadSource;
use Validator;

class LeadSourceValidator
{

    /**
     * Determine if the given lead_source is valid for complete status.
     *
     * @param LeadSource $lead_source
     *
     * @return bool / Validator
     */
    public function complete(LeadSource $lead_source)
    {
        return Validator::make($lead_source->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given lead_source is valid for verify status.
     *
     * @param LeadSource $lead_source
     *
     * @return bool / Validator
     */
    public function verify(LeadSource $lead_source)
    {
        return Validator::make($lead_source->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given lead_source is valid for approve status.
     *
     * @param LeadSource $lead_source
     *
     * @return bool / Validator
     */
    public function approve(LeadSource $lead_source)
    {
        return Validator::make($lead_source->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given lead_source is valid for publish status.
     *
     * @param LeadSource $lead_source
     *
     * @return bool / Validator
     */
    public function publish(LeadSource $lead_source)
    {
        return Validator::make($lead_source->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given lead_source is valid for archive status.
     *
     * @param LeadSource $lead_source
     *
     * @return bool / Validator
     */
    public function archive(LeadSource $lead_source)
    {
        return Validator::make($lead_source->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given lead_source is valid for unpublish status.
     *
     * @param LeadSource $lead_source
     *
     * @return bool / Validator
     */
    public function unpublish(LeadSource $lead_source)
    {
        return Validator::make($lead_source->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
