<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\Lead;
use Validator;

class LeadValidator
{

    /**
     * Determine if the given lead is valid for complete status.
     *
     * @param Lead $lead
     *
     * @return bool / Validator
     */
    public function complete(Lead $lead)
    {
        return Validator::make($lead->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given lead is valid for verify status.
     *
     * @param Lead $lead
     *
     * @return bool / Validator
     */
    public function verify(Lead $lead)
    {
        return Validator::make($lead->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given lead is valid for approve status.
     *
     * @param Lead $lead
     *
     * @return bool / Validator
     */
    public function approve(Lead $lead)
    {
        return Validator::make($lead->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given lead is valid for publish status.
     *
     * @param Lead $lead
     *
     * @return bool / Validator
     */
    public function publish(Lead $lead)
    {
        return Validator::make($lead->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given lead is valid for archive status.
     *
     * @param Lead $lead
     *
     * @return bool / Validator
     */
    public function archive(Lead $lead)
    {
        return Validator::make($lead->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given lead is valid for unpublish status.
     *
     * @param Lead $lead
     *
     * @return bool / Validator
     */
    public function unpublish(Lead $lead)
    {
        return Validator::make($lead->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
