<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\OpportunityStatus;
use Validator;

class OpportunityStatusValidator
{

    /**
     * Determine if the given opportunity_status is valid for complete status.
     *
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool / Validator
     */
    public function complete(OpportunityStatus $opportunity_status)
    {
        return Validator::make($opportunity_status->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given opportunity_status is valid for verify status.
     *
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool / Validator
     */
    public function verify(OpportunityStatus $opportunity_status)
    {
        return Validator::make($opportunity_status->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given opportunity_status is valid for approve status.
     *
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool / Validator
     */
    public function approve(OpportunityStatus $opportunity_status)
    {
        return Validator::make($opportunity_status->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given opportunity_status is valid for publish status.
     *
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool / Validator
     */
    public function publish(OpportunityStatus $opportunity_status)
    {
        return Validator::make($opportunity_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given opportunity_status is valid for archive status.
     *
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool / Validator
     */
    public function archive(OpportunityStatus $opportunity_status)
    {
        return Validator::make($opportunity_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given opportunity_status is valid for unpublish status.
     *
     * @param OpportunityStatus $opportunity_status
     *
     * @return bool / Validator
     */
    public function unpublish(OpportunityStatus $opportunity_status)
    {
        return Validator::make($opportunity_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
