<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\Opportunity;
use Validator;

class OpportunityValidator
{

    /**
     * Determine if the given opportunity is valid for complete status.
     *
     * @param Opportunity $opportunity
     *
     * @return bool / Validator
     */
    public function complete(Opportunity $opportunity)
    {
        return Validator::make($opportunity->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given opportunity is valid for verify status.
     *
     * @param Opportunity $opportunity
     *
     * @return bool / Validator
     */
    public function verify(Opportunity $opportunity)
    {
        return Validator::make($opportunity->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given opportunity is valid for approve status.
     *
     * @param Opportunity $opportunity
     *
     * @return bool / Validator
     */
    public function approve(Opportunity $opportunity)
    {
        return Validator::make($opportunity->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given opportunity is valid for publish status.
     *
     * @param Opportunity $opportunity
     *
     * @return bool / Validator
     */
    public function publish(Opportunity $opportunity)
    {
        return Validator::make($opportunity->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given opportunity is valid for archive status.
     *
     * @param Opportunity $opportunity
     *
     * @return bool / Validator
     */
    public function archive(Opportunity $opportunity)
    {
        return Validator::make($opportunity->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given opportunity is valid for unpublish status.
     *
     * @param Opportunity $opportunity
     *
     * @return bool / Validator
     */
    public function unpublish(Opportunity $opportunity)
    {
        return Validator::make($opportunity->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
