<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\RelationAddress;

class RelationAddressAction
{
    /**
     * Perform the complete action.
     *
     * @param RelationAddress $relation_address
     *
     * @return RelationAddress
     */
    public function complete(RelationAddress $relation_address)
    {
        try {
            $relation_address->status = 'complete';
            return $relation_address->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param RelationAddress $relation_address
     *
     * @return RelationAddress
     */public function verify(RelationAddress $relation_address)
    {
        try {
            $relation_address->status = 'verify';
            return $relation_address->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param RelationAddress $relation_address
     *
     * @return RelationAddress
     */public function approve(RelationAddress $relation_address)
    {
        try {
            $relation_address->status = 'approve';
            return $relation_address->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param RelationAddress $relation_address
     *
     * @return RelationAddress
     */public function publish(RelationAddress $relation_address)
    {
        try {
            $relation_address->status = 'publish';
            return $relation_address->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param RelationAddress $relation_address
     *
     * @return RelationAddress
     */
    public function archive(RelationAddress $relation_address)
    {
        try {
            $relation_address->status = 'archive';
            return $relation_address->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param RelationAddress $relation_address
     *
     * @return RelationAddress
     */
    public function unpublish(RelationAddress $relation_address)
    {
        try {
            $relation_address->status = 'unpublish';
            return $relation_address->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
