<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\RelationAddress;
use Validator;

class RelationAddressValidator
{

    /**
     * Determine if the given relation_address is valid for complete status.
     *
     * @param RelationAddress $relation_address
     *
     * @return bool / Validator
     */
    public function complete(RelationAddress $relation_address)
    {
        return Validator::make($relation_address->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given relation_address is valid for verify status.
     *
     * @param RelationAddress $relation_address
     *
     * @return bool / Validator
     */
    public function verify(RelationAddress $relation_address)
    {
        return Validator::make($relation_address->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given relation_address is valid for approve status.
     *
     * @param RelationAddress $relation_address
     *
     * @return bool / Validator
     */
    public function approve(RelationAddress $relation_address)
    {
        return Validator::make($relation_address->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given relation_address is valid for publish status.
     *
     * @param RelationAddress $relation_address
     *
     * @return bool / Validator
     */
    public function publish(RelationAddress $relation_address)
    {
        return Validator::make($relation_address->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given relation_address is valid for archive status.
     *
     * @param RelationAddress $relation_address
     *
     * @return bool / Validator
     */
    public function archive(RelationAddress $relation_address)
    {
        return Validator::make($relation_address->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given relation_address is valid for unpublish status.
     *
     * @param RelationAddress $relation_address
     *
     * @return bool / Validator
     */
    public function unpublish(RelationAddress $relation_address)
    {
        return Validator::make($relation_address->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
