<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\RelationCommunication;

class RelationCommunicationAction
{
    /**
     * Perform the complete action.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return RelationCommunication
     */
    public function complete(RelationCommunication $relation_communication)
    {
        try {
            $relation_communication->status = 'complete';
            return $relation_communication->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return RelationCommunication
     */public function verify(RelationCommunication $relation_communication)
    {
        try {
            $relation_communication->status = 'verify';
            return $relation_communication->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return RelationCommunication
     */public function approve(RelationCommunication $relation_communication)
    {
        try {
            $relation_communication->status = 'approve';
            return $relation_communication->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return RelationCommunication
     */public function publish(RelationCommunication $relation_communication)
    {
        try {
            $relation_communication->status = 'publish';
            return $relation_communication->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return RelationCommunication
     */
    public function archive(RelationCommunication $relation_communication)
    {
        try {
            $relation_communication->status = 'archive';
            return $relation_communication->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return RelationCommunication
     */
    public function unpublish(RelationCommunication $relation_communication)
    {
        try {
            $relation_communication->status = 'unpublish';
            return $relation_communication->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
