<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\RelationCommunication;
use Validator;

class RelationCommunicationValidator
{

    /**
     * Determine if the given relation_communication is valid for complete status.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return bool / Validator
     */
    public function complete(RelationCommunication $relation_communication)
    {
        return Validator::make($relation_communication->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given relation_communication is valid for verify status.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return bool / Validator
     */
    public function verify(RelationCommunication $relation_communication)
    {
        return Validator::make($relation_communication->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given relation_communication is valid for approve status.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return bool / Validator
     */
    public function approve(RelationCommunication $relation_communication)
    {
        return Validator::make($relation_communication->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given relation_communication is valid for publish status.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return bool / Validator
     */
    public function publish(RelationCommunication $relation_communication)
    {
        return Validator::make($relation_communication->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given relation_communication is valid for archive status.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return bool / Validator
     */
    public function archive(RelationCommunication $relation_communication)
    {
        return Validator::make($relation_communication->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given relation_communication is valid for unpublish status.
     *
     * @param RelationCommunication $relation_communication
     *
     * @return bool / Validator
     */
    public function unpublish(RelationCommunication $relation_communication)
    {
        return Validator::make($relation_communication->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
