<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\RelationStatus;

class RelationStatusAction
{
    /**
     * Perform the complete action.
     *
     * @param RelationStatus $relation_status
     *
     * @return RelationStatus
     */
    public function complete(RelationStatus $relation_status)
    {
        try {
            $relation_status->status = 'complete';
            return $relation_status->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param RelationStatus $relation_status
     *
     * @return RelationStatus
     */public function verify(RelationStatus $relation_status)
    {
        try {
            $relation_status->status = 'verify';
            return $relation_status->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param RelationStatus $relation_status
     *
     * @return RelationStatus
     */public function approve(RelationStatus $relation_status)
    {
        try {
            $relation_status->status = 'approve';
            return $relation_status->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param RelationStatus $relation_status
     *
     * @return RelationStatus
     */public function publish(RelationStatus $relation_status)
    {
        try {
            $relation_status->status = 'publish';
            return $relation_status->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param RelationStatus $relation_status
     *
     * @return RelationStatus
     */
    public function archive(RelationStatus $relation_status)
    {
        try {
            $relation_status->status = 'archive';
            return $relation_status->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param RelationStatus $relation_status
     *
     * @return RelationStatus
     */
    public function unpublish(RelationStatus $relation_status)
    {
        try {
            $relation_status->status = 'unpublish';
            return $relation_status->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
