<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\RelationStatus;
use Validator;

class RelationStatusValidator
{

    /**
     * Determine if the given relation_status is valid for complete status.
     *
     * @param RelationStatus $relation_status
     *
     * @return bool / Validator
     */
    public function complete(RelationStatus $relation_status)
    {
        return Validator::make($relation_status->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given relation_status is valid for verify status.
     *
     * @param RelationStatus $relation_status
     *
     * @return bool / Validator
     */
    public function verify(RelationStatus $relation_status)
    {
        return Validator::make($relation_status->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given relation_status is valid for approve status.
     *
     * @param RelationStatus $relation_status
     *
     * @return bool / Validator
     */
    public function approve(RelationStatus $relation_status)
    {
        return Validator::make($relation_status->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given relation_status is valid for publish status.
     *
     * @param RelationStatus $relation_status
     *
     * @return bool / Validator
     */
    public function publish(RelationStatus $relation_status)
    {
        return Validator::make($relation_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given relation_status is valid for archive status.
     *
     * @param RelationStatus $relation_status
     *
     * @return bool / Validator
     */
    public function archive(RelationStatus $relation_status)
    {
        return Validator::make($relation_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given relation_status is valid for unpublish status.
     *
     * @param RelationStatus $relation_status
     *
     * @return bool / Validator
     */
    public function unpublish(RelationStatus $relation_status)
    {
        return Validator::make($relation_status->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
