<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\RelationType;

class RelationTypeAction
{
    /**
     * Perform the complete action.
     *
     * @param RelationType $relation_type
     *
     * @return RelationType
     */
    public function complete(RelationType $relation_type)
    {
        try {
            $relation_type->status = 'complete';
            return $relation_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param RelationType $relation_type
     *
     * @return RelationType
     */public function verify(RelationType $relation_type)
    {
        try {
            $relation_type->status = 'verify';
            return $relation_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param RelationType $relation_type
     *
     * @return RelationType
     */public function approve(RelationType $relation_type)
    {
        try {
            $relation_type->status = 'approve';
            return $relation_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param RelationType $relation_type
     *
     * @return RelationType
     */public function publish(RelationType $relation_type)
    {
        try {
            $relation_type->status = 'publish';
            return $relation_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param RelationType $relation_type
     *
     * @return RelationType
     */
    public function archive(RelationType $relation_type)
    {
        try {
            $relation_type->status = 'archive';
            return $relation_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param RelationType $relation_type
     *
     * @return RelationType
     */
    public function unpublish(RelationType $relation_type)
    {
        try {
            $relation_type->status = 'unpublish';
            return $relation_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
