<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\RelationType;
use Validator;

class RelationTypeValidator
{

    /**
     * Determine if the given relation_type is valid for complete status.
     *
     * @param RelationType $relation_type
     *
     * @return bool / Validator
     */
    public function complete(RelationType $relation_type)
    {
        return Validator::make($relation_type->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given relation_type is valid for verify status.
     *
     * @param RelationType $relation_type
     *
     * @return bool / Validator
     */
    public function verify(RelationType $relation_type)
    {
        return Validator::make($relation_type->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given relation_type is valid for approve status.
     *
     * @param RelationType $relation_type
     *
     * @return bool / Validator
     */
    public function approve(RelationType $relation_type)
    {
        return Validator::make($relation_type->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given relation_type is valid for publish status.
     *
     * @param RelationType $relation_type
     *
     * @return bool / Validator
     */
    public function publish(RelationType $relation_type)
    {
        return Validator::make($relation_type->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given relation_type is valid for archive status.
     *
     * @param RelationType $relation_type
     *
     * @return bool / Validator
     */
    public function archive(RelationType $relation_type)
    {
        return Validator::make($relation_type->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given relation_type is valid for unpublish status.
     *
     * @param RelationType $relation_type
     *
     * @return bool / Validator
     */
    public function unpublish(RelationType $relation_type)
    {
        return Validator::make($relation_type->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
