<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\Relation;
use Validator;

class RelationValidator
{

    /**
     * Determine if the given relation is valid for complete status.
     *
     * @param Relation $relation
     *
     * @return bool / Validator
     */
    public function complete(Relation $relation)
    {
        return Validator::make($relation->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given relation is valid for verify status.
     *
     * @param Relation $relation
     *
     * @return bool / Validator
     */
    public function verify(Relation $relation)
    {
        return Validator::make($relation->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given relation is valid for approve status.
     *
     * @param Relation $relation
     *
     * @return bool / Validator
     */
    public function approve(Relation $relation)
    {
        return Validator::make($relation->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given relation is valid for publish status.
     *
     * @param Relation $relation
     *
     * @return bool / Validator
     */
    public function publish(Relation $relation)
    {
        return Validator::make($relation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given relation is valid for archive status.
     *
     * @param Relation $relation
     *
     * @return bool / Validator
     */
    public function archive(Relation $relation)
    {
        return Validator::make($relation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given relation is valid for unpublish status.
     *
     * @param Relation $relation
     *
     * @return bool / Validator
     */
    public function unpublish(Relation $relation)
    {
        return Validator::make($relation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
