<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cleancrm\Advancedcrm\Models\Vendor;

class VendorAction
{
    /**
     * Perform the complete action.
     *
     * @param Vendor $vendor
     *
     * @return Vendor
     */
    public function complete(Vendor $vendor)
    {
        try {
            $vendor->status = 'complete';
            return $vendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Vendor $vendor
     *
     * @return Vendor
     */public function verify(Vendor $vendor)
    {
        try {
            $vendor->status = 'verify';
            return $vendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Vendor $vendor
     *
     * @return Vendor
     */public function approve(Vendor $vendor)
    {
        try {
            $vendor->status = 'approve';
            return $vendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Vendor $vendor
     *
     * @return Vendor
     */public function publish(Vendor $vendor)
    {
        try {
            $vendor->status = 'publish';
            return $vendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Vendor $vendor
     *
     * @return Vendor
     */
    public function archive(Vendor $vendor)
    {
        try {
            $vendor->status = 'archive';
            return $vendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Vendor $vendor
     *
     * @return Vendor
     */
    public function unpublish(Vendor $vendor)
    {
        try {
            $vendor->status = 'unpublish';
            return $vendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
