<?php

namespace Cleancrm\Advancedcrm\Workflow;

use Cleancrm\Advancedcrm\Models\Vendor;
use Validator;

class VendorValidator
{

    /**
     * Determine if the given vendor is valid for complete status.
     *
     * @param Vendor $vendor
     *
     * @return bool / Validator
     */
    public function complete(Vendor $vendor)
    {
        return Validator::make($vendor->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given vendor is valid for verify status.
     *
     * @param Vendor $vendor
     *
     * @return bool / Validator
     */
    public function verify(Vendor $vendor)
    {
        return Validator::make($vendor->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given vendor is valid for approve status.
     *
     * @param Vendor $vendor
     *
     * @return bool / Validator
     */
    public function approve(Vendor $vendor)
    {
        return Validator::make($vendor->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given vendor is valid for publish status.
     *
     * @param Vendor $vendor
     *
     * @return bool / Validator
     */
    public function publish(Vendor $vendor)
    {
        return Validator::make($vendor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given vendor is valid for archive status.
     *
     * @param Vendor $vendor
     *
     * @return bool / Validator
     */
    public function archive(Vendor $vendor)
    {
        return Validator::make($vendor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given vendor is valid for unpublish status.
     *
     * @param Vendor $vendor
     *
     * @return bool / Validator
     */
    public function unpublish(Vendor $vendor)
    {
        return Validator::make($vendor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
